==> kdebase-3.1.4.tar.bz2: kdebase-3.1.4/kcontrol/ebrowsing/plugins/ikws/kurisearchfilter.h <==
/*  This file is part of the KDE project
    Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
    Copyright (C) 2000 Yves Arrouye <yves@realnames.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

/* $Id: kurisearchfilter.h,v 1.6 2002/01/25 09:49:54 hausmann Exp $ */

#ifndef __KURISEARCHFILTER_H__
#define __KURISEARCHFILTER_H__

#include <dcopobject.h>
#include <kgenericfactory.h>

#include <kurifilter.h>

class KInstance;

class KURISearchFilter : public KURIFilterPlugin, public DCOPObject
{
    Q_OBJECT
    K_DCOP
public:
    KURISearchFilter(QObject *parent = 0, const char *name = 0,
	             const QStringList &args = QStringList() );
    ~KURISearchFilter();

    virtual bool filterURI( KURIFilterData& ) const;
    virtual KCModule *configModule(QWidget *parent = 0, const char *name = 0) const;
    virtual QString configName() const;

k_dcop:
    virtual void configure();
};

typedef KGenericFactory<KURISearchFilter> KURISeachFilterFactory;

#endif

==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kcontrol/ebrowsing/plugins/ikws/kurisearchfilter.h <==
/*  This file is part of the KDE project
    Copyright (C) 1999 Simon Hausmann <hausmann@kde.org>
    Copyright (C) 2000 Yves Arrouye <yves@realnames.com>
    Copyright (C) 2002, 2003 Dawit Alemayehu <adawit@kde.org>    

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

/* $Id: kurisearchfilter.h,v 1.8 2003/03/07 22:05:31 waba Exp $ */

#ifndef __KURISEARCHFILTER_H__
#define __KURISEARCHFILTER_H__

#include <dcopobject.h>
#include <kgenericfactory.h>

#include <kurifilter.h>

class KInstance;

class KURISearchFilter : public KURIFilterPlugin, public DCOPObject
{
    Q_OBJECT
    K_DCOP
public:
    KURISearchFilter(QObject *parent = 0, const char *name = 0, 
                     const QStringList &args = QStringList() );
    ~KURISearchFilter();

    virtual bool filterURI( KURIFilterData& ) const;
    virtual KCModule *configModule(QWidget *parent = 0, const char *name = 0) const;
    virtual QString configName() const;

k_dcop:
    virtual void configure();
};

#endif
